@@ -340,7 +340,7 @@ macrotable_cleanup(void)
 
 static
 struct macro *
-macrotable_findlen(const char *name, size_t len, bool remove)
+macrotable_findlen(const char *name, size_t len, bool remove_it)
 {
 	unsigned hash;
 	struct macroarray *bucket;
@@ -361,7 +361,7 @@ macrotable_findlen(const char *name, size_t len, bool remove)
 		}
 		mlen = strlen(m->name);
 		if (len == mlen && !memcmp(name, m->name, len)) {
-			if (remove) {
+			if (remove_it) {
 				if (i < num-1) {
 					m2 = macroarray_get(bucket, num-1);
 					macroarray_set(bucket, i, m2);
@@ -377,9 +377,9 @@ macrotable_findlen(const char *name, size_t len, bool remove)
 
 static
 struct macro *
-macrotable_find(const char *name, bool remove)
+macrotable_find(const char *name, bool remove_it)
 {
-	return macrotable_findlen(name, strlen(name), remove);
+	return macrotable_findlen(name, strlen(name), remove_it);
 }
 
 static
@@ -892,8 +892,9 @@ expand_domacro(struct expstate *es, struct place *p)
 		return;
 	}
 
-	assert(es->curmacro->inuse == false);
-	es->curmacro->inuse = true;
+	m = es->curmacro;
+	assert(m->inuse == false);
+	m->inuse = true;
 
 	newbuf = expand_substitute(p, es);
 	newbuf2 = macroexpand(p, newbuf, strlen(newbuf), false);
@@ -902,7 +903,7 @@ expand_domacro(struct expstate *es, struct place *p)
 	doexpand(es, p, newbuf2, strlen(newbuf2));
 	dostrfree(newbuf2);
 
-	es->curmacro->inuse = false;
+	m->inuse = false;
 }
 
 /*
@@ -970,7 +971,6 @@ expand_got_word(struct expstate *es, struct place *p,
 		} else if (!m->hasparams) {
 			es->curmacro = m;
 			expand_domacro(es, p);
-			es->curmacro = NULL;
 		} else {
 			es->curmacro = m;
 			es->state = ES_WANTLPAREN;
