@@ -27,8 +27,8 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <stdbool.h>
 #include <stddef.h>
+#include "bool.h"
 
 struct place;
 
@@ -62,6 +62,7 @@ size_t notrailingws(char *buf, size_t len);
 bool is_identifier(const char *str);
 
 /* in place.c */
+void complain_init(const char *progname);
 void complain(const struct place *, const char *fmt, ...) PF(2, 3);
 void complain_fail(void);
 bool complain_failed(void);
